@@ -94,6 +94,7 @@ sub handle_type {
                 $has_err++;
                 $validator->log_error("schema error: invalid attribute name `$name': $k");
             }
+            next if $name =~ /^(ui)$/;
             if ($suffix && $suffix !~ /^(errmsg)$/) {
                 $has_err++;
                 $validator->log_error("schema error: unknown attribute suffix `$suffix': $k");
@@ -338,6 +339,16 @@ sub handle_attr_between {
     $self->handle_attr_max($data, $arg->[1]);
 }
 
+=head2 type_in_english($attrhash, ...)
+
+Show an English representation of this data type.
+
+=cut
+
+sub type_in_english {
+    "base";
+}
+
 =head1 AUTHOR
 
 Steven Haryanto, C<< <steven at masterweb.net> >>
